@@ -335,12 +335,10 @@ class TicketDetail(TicketDetail):
     id:6 ref
     summary
     # standby feedback closed
-    parent
-    TicketsByParent
+    description
     """
 
     more2 = """
-    description
     upgrade_notes
     uploads.UploadsByController
     # tickets.CheckListItemsByTicket
@@ -369,9 +367,14 @@ class TicketDetail(TicketDetail):
     # """, label=_("Even more"))
 
     links = dd.Panel("""
-    comments.CommentsByMentioned LinksByTicket
+    links_left comments.CommentsByMentioned #LinksByTicket
     """, label=_("Links"))
 
+    links_left = """
+    parent
+    TicketsByParent
+    """
+
 class TicketInsertLayout(dd.InsertLayout):
     main = """
     summary #private:20
@@ -460,5 +463,5 @@ class TicketsByParent(Tickets):
     required_roles = dd.login_required(Reporter)
     # label = _("Known problems")
     master_key = 'parent'
-    column_names = "priority overview:50 quick_assign_to #ticket_type #workflow_buttons *"
+    column_names = "priority id summary:50 quick_assign_to #ticket_type #workflow_buttons *"
     details_of_master_template = _("Children of %(master)s")
